summaryrefslogtreecommitdiff
path: root/MdeModulePkg/Universal/Network/Udp4Dxe/Udp4Impl.c
diff options
context:
space:
mode:
Diffstat (limited to 'MdeModulePkg/Universal/Network/Udp4Dxe/Udp4Impl.c')
-rw-r--r--MdeModulePkg/Universal/Network/Udp4Dxe/Udp4Impl.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/MdeModulePkg/Universal/Network/Udp4Dxe/Udp4Impl.c b/MdeModulePkg/Universal/Network/Udp4Dxe/Udp4Impl.c
index df95077aac..b258439a50 100644
--- a/MdeModulePkg/Universal/Network/Udp4Dxe/Udp4Impl.c
+++ b/MdeModulePkg/Universal/Network/Udp4Dxe/Udp4Impl.c
@@ -200,10 +200,10 @@ Udp4DeliverDgram (
);
/**
- This function demultiplexes the received udp datagram to the apropriate instances.
+ This function demultiplexes the received udp datagram to the appropriate instances.
@param[in] Udp4Service Pointer to the udp service context data.
- @param[in] NetSession Pointer to the EFI_NET_SESSION_DATA abstrated from
+ @param[in] NetSession Pointer to the EFI_NET_SESSION_DATA abstracted from
the received datagram.
@param[in] Packet Pointer to the buffer containing the received udp
datagram.
@@ -1586,10 +1586,10 @@ Udp4DeliverDgram (
/**
- This function demultiplexes the received udp datagram to the apropriate instances.
+ This function demultiplexes the received udp datagram to the appropriate instances.
@param[in] Udp4Service Pointer to the udp service context data.
- @param[in] NetSession Pointer to the EFI_NET_SESSION_DATA abstrated from
+ @param[in] NetSession Pointer to the EFI_NET_SESSION_DATA abstracted from
the received datagram.
@param[in] Packet Pointer to the buffer containing the received udp
datagram.
@@ -1707,7 +1707,7 @@ Udp4SendPortUnreach (
IpSender = IpIoFindSender (&IpIo, NetSession->IpVersion, &NetSession->Dest);
if (IpSender == NULL) {
//
// No apropriate sender, since we cannot send out the ICMP message through
// the default zero station address IP instance, abort.
//
return;
@@ -1716,7 +1716,7 @@ Udp4SendPortUnreach (
IpHdr = NetSession->IpHdr.Ip4Hdr;
//
- // Calculate the requried length of the icmp error message.
+ // Calculate the required length of the icmp error message.
//
Len = sizeof (IP4_ICMP_ERROR_HEAD) + (EFI_IP4_HEADER_LEN (IpHdr) -
sizeof (IP4_HEAD)) + ICMP_ERROR_PACKET_LENGTH;
@@ -1707,7 +1707,7 @@ Udp4SendPortUnreach (
if (IpSender == NULL) {
//
- // No apropriate sender, since we cannot send out the ICMP message through
+ // No appropriate sender, since we cannot send out the ICMP message through
// the default zero station address IP instance, abort.
//